@@ -9,4 +9,8 @@ class Constants():
           "REJECTED":"rejected",\
           "FP":"fp", \
           "LIBRARY":"library", \
-          "ACCEPTRISK": 'acceptrisk'}
\ No newline at end of file
+          "ACCEPTRISK": 'acceptrisk'}
+
+     AGENT_TYPE = [ "CLI", "MAVEN", "GRADLE", "JENKINS", "BAMBOO", "CIRCLECI", "CODESHIP", "PIPELINES", "TRAVIS", "WINDOWSCI" ]
+
+     SCA_EVENT_GROUP = [ 'WORKSPACE', 'AGENT', 'SCAN', 'PROJECT', 'RULES']
\ No newline at end of file
